@@ -17,7 +17,7 @@ Usage::
     list_luna_clients_paginator: ListLunaClientsPaginator = client.get_paginator("list_luna_clients")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_cloudhsm.type_defs import (
     ListHapgsResponseTypeDef,
@@ -32,38 +32,38 @@ __all__ = ("ListHapgsPaginator", "ListHsmsPaginator", "ListLunaClientsPaginator"
 
 class ListHapgsPaginator(Boto3Paginator):
     """
-    [Paginator.ListHapgs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs)
+    [Paginator.ListHapgs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListHapgsResponseTypeDef, None, None]:
+    ) -> Iterator[ListHapgsResponseTypeDef]:
         """
-        [ListHapgs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs.paginate)
+        [ListHapgs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs.paginate)
         """
 
 
 class ListHsmsPaginator(Boto3Paginator):
     """
-    [Paginator.ListHsms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms)
+    [Paginator.ListHsms documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListHsmsResponseTypeDef, None, None]:
+    ) -> Iterator[ListHsmsResponseTypeDef]:
         """
-        [ListHsms.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms.paginate)
+        [ListHsms.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms.paginate)
         """
 
 
 class ListLunaClientsPaginator(Boto3Paginator):
     """
-    [Paginator.ListLunaClients documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients)
+    [Paginator.ListLunaClients documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[ListLunaClientsResponseTypeDef, None, None]:
+    ) -> Iterator[ListLunaClientsResponseTypeDef]:
         """
-        [ListLunaClients.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients.paginate)
+        [ListLunaClients.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.25/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients.paginate)
         """
